SystemOrganization addCategory: #GODFilterTests!

TestCase subclass: #FILTConferenceFilterTest
	instanceVariableNames: 'god data'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODFilterTests'!

!FILTConferenceFilterTest methodsFor: 'initialize-release' stamp: 'CER 10/18/2014 19:12'!
setUp

	data := OrderedCollection new.

	data add: TUMock new.
	(data last)
	when: #categories do: [ 'Theory of Computation' ];
	when: #importantDates do: [ ((TUMock new)
		when: #deadlineDate do: [ (Date readFromString: '01 Feb 2015') ];
		when: #startDate do: [ (Date readFromString: '28 Feb 2015')];
		when: #endDate do: [ (Date readFromString: '03 Mar 2015') ]) ];
	when: #name do: [ 'Automaton' ].

	data add: TUMock new.
	(data last)
	when: #categories do: [ 'Theory of Computation' ];
	when: #importantDates do: [ ((TUMock new)
		when: #deadlineDate do: [ (Date readFromString: '04 Feb 2015') ];
		when: #startDate do: [ (Date readFromString: '01 Mar 2015')];
		when: #endDate do: [ (Date readFromString: '04 Mar 2015') ]) ];
	when: #name do: [ 'Automaton' ].

	data add: TUMock new.
	(data last)
	when: #categories do: [ 'Stochastic Processes and Applications' ];
	when: #importantDates do: [ ((TUMock new)
		when: #deadlineDate do: [ (Date readFromString: '02 Feb 2015') ];
		when: #startDate do: [ (Date readFromString: '02 Mar 2015')];
		when: #endDate do: [ (Date readFromString: '06 Mar 2015') ]) ];
	when: #name do: [ 'Statistical' ].

	data add: TUMock new.
	(data last)
	when: #categories do: [ 'Theory of Computation' ];
	when: #importantDates do: [ ((TUMock new)
		when: #deadlineDate do: [ (Date readFromString: '03 Feb 2015') ];
		when: #startDate do: [ (Date readFromString: '01 Mar 2015')];
		when: #endDate do: [ (Date readFromString: '07 Mar 2015') ]) ];
	when: #name do: [ 'Graph Theory' ].! !

!FILTConferenceFilterTest methodsFor: 'tests' stamp: 'CER 10/18/2014 19:17'!
testFilterByGCSearchFilter
	"Test conference filter"
	
	| searchFilter result |

      searchFilter := GCSearchFilter new.
	searchFilter category: 'Theory of Computation'.
	searchFilter deadlineDate: (Date readFromString: '03 Feb 2015').
	searchFilter startDate: (Date readFromString: '01 Jan 2015').
	searchFilter endDate: (Date readFromString: '07 Mar 2015').
	searchFilter searchKey: 'Automaton'.
	
	result := god filter: data byGCSearchFilter: searchFilter.
	
	self assert: result size = 1! !

TestCase subclass: #FILTMainFilterTest
	instanceVariableNames: 'setOfGodData god data'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODFilterTests'!

FILTMainFilterTest class
	instanceVariableNames: 'gf'!

FILTMainFilterTest class
	instanceVariableNames: 'gf'!

!FILTMainFilterTest methodsFor: 'initialize-release' stamp: 'ym 10/10/2014 20:30'!
setUp
	| mock|

	god := FILTMainFilter new.
	
	
	data := OrderedCollection new.
	mock := TUMock new.
	mock when: #tags do: [ { 'tag1'} ].
	mock when: #content do: [ 'content1' ].
	mock when: #origin do: [ 'origin1' ].
	mock when: #title do: [ 'title1' ].
	data add: mock.	
	mock := TUMock new.
	mock when: #tags do: [ { 'tag2' . 'tag1' } ].
	mock when: #content do: [ 'content2' ].
	mock when: #origin do: [ 'origin2' ].
	mock when: #title do: [ 'title2' ].
	data add: mock.	
	mock := TUMock new.
	mock when: #tags do: [ { 'tag2' } ].
	mock when: #content do: [ 'content2' ].
	mock when: #origin do: [ 'origin1' ].
	mock when: #title do: [ 'title3' ].
	data add: mock.	! !

!FILTMainFilterTest methodsFor: 'tests' stamp: 'ym 10/10/2014 20:31'!
testFIlterByTag
	| isSuccess result |
	result := (god filter: data byTags: 'tag1') collect: #tags.
	isSuccess := true.
	{{'tag1'} . {'tag2' . 'tag1'}} do: [:each|
	(result includes: each) ifFalse: [isSuccess := false]
	].
	self assert: isSuccess! !

!FILTMainFilterTest methodsFor: 'tests' stamp: 'ym 10/10/2014 20:35'!
testFilterByContent
	| isSuccess result |
	result := (god filter: data byContent: 'content2') collect: #content.
	isSuccess := true.
	{ 'content2' . 'content2' } do: [:each|
	result remove: each ifAbsent: [isSuccess := false]
	].
	self assert: isSuccess! !

!FILTMainFilterTest methodsFor: 'tests' stamp: 'ym 10/10/2014 20:35'!
testFilterByOrigin
	| isSuccess result |
	result := (god filter: data byOrigin: 'origin1') collect: #origin.
	isSuccess := true.
	{'origin1' . 'origin1' } do: [:each|
	result remove: each ifAbsent: [isSuccess := false]
	].
	self assert: isSuccess! !

!FILTMainFilterTest methodsFor: 'tests' stamp: 'ym 10/10/2014 20:35'!
testFilterByTitle
	| isSuccess result |
	result := (god filter: data byTitle: 'title3') collect: #title.
	isSuccess := true.
	{ 'title3' } do: [:each|
	result remove: each ifAbsent: [isSuccess := false]
	].
	self assert: isSuccess! !

TestCase subclass: #FILTTextFilterTest
	instanceVariableNames: 'text god'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODFilterTests'!

!FILTTextFilterTest methodsFor: 'initialize-release' stamp: 'CER 10/16/2014 17:02'!
setUp
	god := 	FILTTextFilter new.	

	text := '
	<div> blablabla
		<div> XXX
			<div> YYY 
			</div>
		</div>
		<div> ZZZ 
		</div>
	</div>'.! !

!FILTTextFilterTest methodsFor: 'tests' stamp: 'ym 10/10/2014 21:11'!
testFilterTextBetweenAnd
	"Teste do mtodo filterText:Between:And:"
	
	| mark1 mark2 expected result |
	mark1 := 'div>'.
	mark2 :=  '<'.
	 
	expected := {' blablabla
		' . ' XXX
			' . ' YYY 
			' . '
		' . '
		' . ' ZZZ 
		' . '
	'} asOrderedCollection.
	
	result := god filterText: text between: mark1 and: mark2.
	
	self assert: result = expected
	! !
